@@ -17,17 +17,17 @@
 #   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 
-"""Save an item retrieved from the Twitter API to the database"""
+"""Save an item retrieved from the Twitter API to the database."""
 
 
 __all__ = ["BaseItemSaver"]
 
 
 class BaseItemSaver:
-    """Save an item retrieved from the Twitter API to the database"""
+    """Save an item retrieved from the Twitter API to the database."""
 
     shutdown = None  # poor attempt at a singleton?
 
     def __init__(self, shutdown):
-        """Initialise an BaseItemSaver"""
+        """Initialise an BaseItemSaver."""
         self.shutdown = shutdown
