@@ -26,7 +26,7 @@ import sys
 
 import sqlalchemy
 
-from ..engine import engine
+from .engine import engine
 
 
 # for now, schema updates are SQL only and work on PostgreSQL, only.
@@ -34,8 +34,6 @@ from ..engine import engine
 SCHEMA_UPDATES = {
     # 0 -> 1
     1: """
-        BEGIN;
-
         ALTER TABLE
             places
         ADD COLUMN
@@ -71,24 +69,16 @@ SCHEMA_UPDATES = {
             places_country_code_fkey
                 FOREIGN KEY (country_code)
                 REFERENCES countries (code);
-
-        COMMIT;
     """,
     # 1 -> 2
     2: """
-        BEGIN;
-
         ALTER TABLE
             places
         ADD COLUMN
             geom GEOMETRY('GEOMETRYCOLLECTION', 4326);
-
-        COMMIT;
     """,
     # 2 -> 3
     3: """
-        BEGIN;
-
         ALTER TABLE
             search_terms
         DROP CONSTRAINT
@@ -124,13 +114,9 @@ SCHEMA_UPDATES = {
             users
         USING
             BTREE(username);
-
-        COMMIT;
     """,
     # 3 -> 4
     4: """
-        BEGIN;
-
         UPDATE
             countries
         SET
@@ -315,13 +301,9 @@ SCHEMA_UPDATES = {
         DROP COLUMN
             profile_image_url_url
                 CASCADE;
-
-        COMMIT;
     """,
     # 4 -> 5
     5: """
-        BEGIN;
-
         ALTER TABLE
             tweet_references
         DROP CONSTRAINT
@@ -331,8 +313,88 @@ SCHEMA_UPDATES = {
             referenced_tweet_id,
             reference_type_id
         );
+    """,
+    # 5 -> 6
+    6: """
+        ALTER TABLE
+            tweets
+        ADD COLUMN
+            like_count BIGINT,
+        ADD COLUMN
+            quote_count BIGINT,
+        ADD COLUMN
+            reply_count BIGINT,
+        ADD COLUMN
+            retweet_count BIGINT;
 
-        COMMIT;
+        ALTER TABLE
+            users
+        ADD COLUMN
+            followers_count BIGINT,
+        ADD COLUMN
+            following_count BIGINT,
+        ADD COLUMN
+            tweet_count BIGINT,
+        ADD COLUMN
+            listed_count BIGINT;
+    """,
+    # 6 -> 7
+    7: """
+        CREATE INDEX ix_countries_name
+            ON countries
+            USING BTREE(name);
+
+        CREATE INDEX ix_media_items_media_type_id
+            ON media_items
+            USING BTREE(media_type_id);
+
+        CREATE INDEX ix_places_container_id
+            ON places
+            USING BTREE(container_id);
+
+        CREATE INDEX ix_places_country_code
+            ON places
+            USING BTREE(country_code);
+
+        CREATE INDEX ix_places_name
+            ON places
+            USING BTREE(name);
+
+        CREATE INDEX ix_places_place_type_id
+            ON places
+            USING BTREE(place_type_id);
+
+        CREATE INDEX ix_tweets_author_id
+            ON tweets
+            USING BTREE(author_id);
+
+        CREATE INDEX ix_tweets_conversation_id
+            ON tweets
+            USING BTREE(conversation_id);
+
+        CREATE INDEX ix_tweets_created_at
+            ON tweets
+            USING BTREE(created_at);
+
+        CREATE INDEX ix_tweets_language_language
+            ON tweets
+            USING BTREE(language_language);
+
+        CREATE INDEX ix_tweets_place_id
+            ON tweets
+            USING BTREE(place_id);
+
+        CREATE UNIQUE INDEX ix_urls_url
+            ON urls
+            USING BTREE(url);
+
+        CREATE INDEX ix_users_created_at
+            ON users
+            USING BTREE(created_at);
+
+        CREATE INDEX ix_users_name
+            ON users
+            USING BTREE(name);
     """
 }
 
@@ -358,7 +420,7 @@ class DatabaseSchemaUpdater:
 
     @property
     def installed_version(self):
-        """Current version."""
+        """Return current version."""
         with engine.connect() as connection:
             installed_version = (
                 connection.execute(
@@ -384,7 +446,8 @@ class DatabaseSchemaUpdater:
                     installed_version,
                     installed_version + 1
                 ),
-                file=sys.stderr
+                file=sys.stderr,
+                flush=True  # so that we don’t seem without work
             )
             with engine.begin() as connection:
                 next_version = self.installed_version + 1
