@@ -52,10 +52,10 @@ class User(Base):
 
     id = sqlalchemy.Column(sqlalchemy.BigInteger, primary_key=True)
     username = sqlalchemy.Column(sqlalchemy.Text, index=True)
-    name = sqlalchemy.Column(sqlalchemy.Text)
+    name = sqlalchemy.Column(sqlalchemy.Text, index=True)
     description = sqlalchemy.Column(sqlalchemy.Text)
     location = sqlalchemy.Column(sqlalchemy.Text)
-    created_at = sqlalchemy.Column(sqlalchemy.DateTime(timezone=True))
+    created_at = sqlalchemy.Column(sqlalchemy.DateTime(timezone=True), index=True)
 
     protected = sqlalchemy.Column(sqlalchemy.Boolean)
     verified = sqlalchemy.Column(sqlalchemy.Boolean)
@@ -85,6 +85,11 @@ class User(Base):
         "Tweet", secondary="mentions", back_populates="mentions"
     )
 
+    followers_count = sqlalchemy.Column(sqlalchemy.BigInteger)
+    following_count = sqlalchemy.Column(sqlalchemy.BigInteger)
+    listed_count = sqlalchemy.Column(sqlalchemy.BigInteger)
+    tweet_count = sqlalchemy.Column(sqlalchemy.BigInteger)
+
     @classmethod
     def _pseudonymise_api_data(cls, data):
         for identifier in [
