@@ -17,7 +17,7 @@
 #   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 
-"""Save a tweet to the database"""
+"""Save a tweet to the database."""
 
 
 __all__ = ["TweetSaver"]
@@ -43,10 +43,10 @@ from ..config import Config
 
 
 class TweetSaver(BaseItemSaver):
-    """Save a tweet to the database"""
+    """Save a tweet to the database."""
 
     def _save_tweet(self, data, session, search_term=None):
-        """Save a tweet to the database"""
+        """Save a tweet to the database."""
         with Config() as config:
             if config["pseudonymise"]:
                 data = Tweet._pseudonymise_api_data(data)
@@ -54,10 +54,15 @@ class TweetSaver(BaseItemSaver):
         with session.begin():
             tweet = session.get(Tweet, int(data["id"])) or Tweet(id=int(data["id"]))
 
-            if not tweet.text:
-                # no properties except primary key
-                # (yes, it’s a proxy, but a strong one:
-                # there really should not be any tweet with a NULL text)
+            if (
+                    tweet.text is None
+                    or tweet.like_count is None
+                    or tweet.quote_count is None
+                    or tweet.reply_count is None
+                    or tweet.retweet_count is None
+            ):
+                # some important properties missing:
+                # probably we did not save this tweet (properly) yet
 
                 session.add(tweet)
                 tweet.created_at = dateparser.parse(data["created_at"])
@@ -154,7 +159,7 @@ class TweetSaver(BaseItemSaver):
                 if "referenced_tweets" in data:
                     for referenced_tweet in data["referenced_tweets"]:
                         tweet_reference = TweetReference()
-                        tweet_reference.reference_type = (
+                        reference_type = (
                             session.query(TweetReferenceType)
                             .filter(TweetReferenceType.reference_type == referenced_tweet["type"])
                             .first()
@@ -163,17 +168,38 @@ class TweetSaver(BaseItemSaver):
                                 reference_type=referenced_tweet["type"]
                             )
                         )
-                        tweet_reference.referenced_tweet = (
+                        referenced_tweet = (
                             session.get(Tweet, int(referenced_tweet["id"]))
                             or Tweet(id=int(referenced_tweet["id"]))
                         )
-                        tweet.referenced_tweets.append(tweet_reference)
+
+                        tweet_reference = session.get(
+                            TweetReference,
+                            {
+                                "referencing_tweet_id": tweet.id,
+                                "referenced_tweet_id": referenced_tweet.id,
+                                "reference_type_id": reference_type.id
+                            }
+                        )
+                        if not tweet_reference:
+                            tweet_reference = TweetReference(
+                                referenced_tweet=referenced_tweet,
+                                reference_type=reference_type
+                            )
+                            tweet.referenced_tweets.append(tweet_reference)
+
                         session.add(tweet_reference.referenced_tweet)
                         session.flush()
                         # not sure why we have to flush here, but session.get()
                         # does not return any pending objects -> might lead to
                         # duplicate tweets in the same commit (==merge conflict)
 
+                if "public_metrics" in data:
+                    tweet.like_count = data["public_metrics"]["like_count"]
+                    tweet.quote_count = data["public_metrics"]["quote_count"]
+                    tweet.reply_count = data["public_metrics"]["reply_count"]
+                    tweet.retweet_count = data["public_metrics"]["retweet_count"]
+
                 if search_term is not None:
                     tweet.search_terms = [search_term]
 
